==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControlUI/src/com/clustercontrol/accesscontrol/composite/UserListComposite.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.accesscontrol.composite;

import java.util.ArrayList;

import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Table;

import com.clustercontrol.accesscontrol.action.GetUserList;
import com.clustercontrol.accesscontrol.action.GetUserListTableDefine;
import com.clustercontrol.accesscontrol.bean.UserListTableDefine;
import com.clustercontrol.accesscontrol.composite.action.UserDoubleClickListener;
import com.clustercontrol.bean.Property;
import com.clustercontrol.composite.CommonTableViewer;
import com.clustercontrol.util.Messages;

/**
 * 桼ݥåȥ饹
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class UserListComposite extends Composite {
    protected CommonTableViewer m_viewer = null;

    protected Label m_labelType = null;
    
    protected Label m_labelCount = null;
    
    protected String m_uid = null;

    /**
     * 󥹥ȥ饯
     * 
     * @param parent
     * @param style
     * @since 2.0.0
     */
    public UserListComposite(Composite parent, int style) {
        super(parent, style);
        initialize();
    }

    /**
     * 
     * 
     * @since 2.0.0
     */
    private void initialize() {
        GridLayout layout = new GridLayout(1, true);
        this.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        m_labelType = new Label(this, SWT.LEFT);
        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        m_labelType.setLayoutData(gridData);

        
        Table table = new Table(this, SWT.H_SCROLL | SWT.V_SCROLL
                | SWT.FULL_SELECTION | SWT.SINGLE);
        table.setHeaderVisible(true);
        table.setLinesVisible(true);

        gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        gridData.horizontalSpan = 1;
        table.setLayoutData(gridData);

        m_labelCount = new Label(this, SWT.RIGHT);
        gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        m_labelCount.setLayoutData(gridData);

        m_viewer = new CommonTableViewer(table);
        m_viewer.createTableColumn(GetUserListTableDefine.get(),
        		UserListTableDefine.SORT_COLUMN_INDEX,
        		UserListTableDefine.SORT_ORDER);

        m_viewer.addDoubleClickListener(new UserDoubleClickListener(this));
    }

    /**
     * 
     * 
     * @since 2.0.0
     */
    public void update() {
        ArrayList userInfo = null;

        //桼
        GetUserList getUserList = new GetUserList();
        userInfo = getUserList.getAll();
        if(userInfo == null){
        	userInfo = new ArrayList();
        }
        
        m_viewer.setInput(userInfo);

        m_labelType.setText("");
        Object[] args = { new Integer(userInfo.size()) };
        m_labelCount.setText(Messages.getString("records", args));
    }

    /**
     * 
     * 
     * @param condition
     *            ե륿
     * @since 2.0.0
     */
    public void update(Property condition) {
        ArrayList userInfo = null;

        //
        GetUserList getUserList = new GetUserList();
        userInfo = getUserList.get(condition);

        m_viewer.setInput(userInfo);

        m_labelType.setText(Messages.getString("filtered.list"));
        Object[] args = { new Integer(userInfo.size()) };
        m_labelCount.setText(Messages.getString("filtered.records", args));
    }

    /**
     * ΥݥåȤѤơ֥ӥ塼֤ޤ
     * 
     * @return ơ֥ӥ塼
     */
    public TableViewer getTableViewer() {
        return m_viewer;
    }

    /**
     * ΥݥåȤѤơ֥֤ޤ
     * 
     * @return ơ֥
     */
    public Table getTable() {
        return m_viewer.getTable();
    }

    /**
     * @return Returns the uid.
     */
    public String getUid() {
        return m_uid;
    }

    /**
     * @param uid
     *            The uid to set.
     */
    public void setUid(String uid) {
    	m_uid = uid;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControlUI/src/com/clustercontrol/accesscontrol/composite/UserListComposite.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.accesscontrol.composite;

import java.util.ArrayList;

import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Table;

import com.clustercontrol.accesscontrol.action.GetUserList;
import com.clustercontrol.accesscontrol.action.GetUserListTableDefine;
import com.clustercontrol.accesscontrol.bean.UserListTableDefine;
import com.clustercontrol.accesscontrol.composite.action.UserDoubleClickListener;
import com.clustercontrol.bean.Property;
import com.clustercontrol.composite.CommonTableViewer;
import com.clustercontrol.util.Messages;

/**
 * ユーザ一覧コンポジットクラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class UserListComposite extends Composite {
    protected CommonTableViewer m_viewer = null;

    protected Label m_labelType = null;
    
    protected Label m_labelCount = null;
    
    protected String m_uid = null;

    /**
     * コンストラクタ
     * 
     * @param parent
     * @param style
     * @since 2.0.0
     */
    public UserListComposite(Composite parent, int style) {
        super(parent, style);
        initialize();
    }

    /**
     * 初期化処理
     * 
     * @since 2.0.0
     */
    private void initialize() {
        GridLayout layout = new GridLayout(1, true);
        this.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        m_labelType = new Label(this, SWT.LEFT);
        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        m_labelType.setLayoutData(gridData);

        
        Table table = new Table(this, SWT.H_SCROLL | SWT.V_SCROLL
                | SWT.FULL_SELECTION | SWT.SINGLE);
        table.setHeaderVisible(true);
        table.setLinesVisible(true);

        gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        gridData.horizontalSpan = 1;
        table.setLayoutData(gridData);

        m_labelCount = new Label(this, SWT.RIGHT);
        gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        m_labelCount.setLayoutData(gridData);

        m_viewer = new CommonTableViewer(table);
        m_viewer.createTableColumn(GetUserListTableDefine.get(),
        		UserListTableDefine.SORT_COLUMN_INDEX,
        		UserListTableDefine.SORT_ORDER);

        m_viewer.addDoubleClickListener(new UserDoubleClickListener(this));
    }

    /**
     * 更新処理
     * 
     * @since 2.0.0
     */
    public void update() {
        ArrayList userInfo = null;

        //ユーザ一覧情報取得
        GetUserList getUserList = new GetUserList();
        userInfo = getUserList.getAll();
        if(userInfo == null){
        	userInfo = new ArrayList();
        }
        
        m_viewer.setInput(userInfo);

        m_labelType.setText("");
        Object[] args = { new Integer(userInfo.size()) };
        m_labelCount.setText(Messages.getString("records", args));
    }

    /**
     * 更新処理
     * 
     * @param condition
     *            フィルタ条件
     * @since 2.0.0
     */
    public void update(Property condition) {
        ArrayList userInfo = null;

        //ジョブ履歴情報取得
        GetUserList getUserList = new GetUserList();
        userInfo = getUserList.get(condition);

        m_viewer.setInput(userInfo);

        m_labelType.setText(Messages.getString("filtered.list"));
        Object[] args = { new Integer(userInfo.size()) };
        m_labelCount.setText(Messages.getString("filtered.records", args));
    }

    /**
     * このコンポジットが利用するテーブルビューアを返します。
     * 
     * @return テーブルビューア
     */
    public TableViewer getTableViewer() {
        return m_viewer;
    }

    /**
     * このコンポジットが利用するテーブルを返します。
     * 
     * @return テーブル
     */
    public Table getTable() {
        return m_viewer.getTable();
    }

    /**
     * @return Returns the uid.
     */
    public String getUid() {
        return m_uid;
    }

    /**
     * @param uid
     *            The uid to set.
     */
    public void setUid(String uid) {
    	m_uid = uid;
    }
}
